OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "포함된 메시지 %s",
    "Important mail" : "중요 메일",
    "No message found yet" : "메시지 없음",
    "Set up an account" : "계정 설정",
    "Unread mail" : "읽지 않은 메일",
    "Important" : "중요",
    "Work" : "직장",
    "Personal" : "개인",
    "To Do" : "할 일",
    "Later" : "나중에",
    "Mail" : "메일",
    "You are reaching your mailbox quota limit for {account_email}" : "{account_email} 계정의 최대 메일 수에 도달했습니다 ",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "현재 편지함 용량의 {percentage}가 사용중입니다. 불필요한 이메일을 삭제하여 용량을 확보하십시오.",
    "Mails" : "메일",
    "💌 A mail app for Nextcloud" : "Nextcloud 메일 앱",
    "Your session has expired. The page will be reloaded." : "세션이 만료되었습니다. 페이지를 다시 불러옵니다.",
    "Drafts are saved in:" : "초안은 다음 위치에 저장:",
    "Sent messages are saved in:" : "보낸 메시지는 다음 위치에 저장:",
    "Deleted messages are moved in:" : "삭제된 메시지는 다음 위치로 이동:",
    "Archived messages are moved in:" : "보관된 메시지가 다음으로 이동됨: ",
    "Snoozed messages are moved in:" : "다시 알릴 메시지는 다음 위치로 이동:",
    "Junk messages are saved in:" : "스팸 메시지는 다음 위치에 저장:",
    "Connecting" : "연결 중",
    "Reconnect Google account" : "구글 계정 재연결",
    "Sign in with Google" : "구글 계정으로 로그인",
    "Save" : "저장",
    "Connect" : "연결",
    "Checking mail host connectivity" : "메일 호스트 연결 체크 중",
    "Configuration discovery failed. Please use the manual settings" : "설정 탐색을 실패했습니다. 수동 설정을 사용하십시오.",
    "Password required" : "암호가 필요함",
    "Testing authentication" : "인증 시험 중",
    "Awaiting user consent" : "사용자의 동의를 기다리는 중",
    "Account created. Please follow the pop-up instructions to link your Google account" : "계정 생성됨. 팝업 창의 지시에 따라 구글 계정에 연결하십시오",
    "Loading account" : "계정 불러오는 중",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "계정 갱신됨. 팝업 창의 지시에 따라 구글 계정에 재연결하십시오",
    "Account updated" : "계정 업데이트됨",
    "IMAP server is not reachable" : "IMAP 서버에 연결할 수 없음",
    "SMTP server is not reachable" : "SMTP 서버에 연결할 수 없음",
    "IMAP username or password is wrong" : "IMAP 사용자명 또는 암호가 잘못되었습니다",
    "SMTP username or password is wrong" : "SMTP 사용자명 또는 암호가 잘못되었습니다",
    "IMAP connection failed" : "IMAP 연결 실패",
    "SMTP connection failed" : "SMTP 연결 실패",
    "Authorization pop-up closed" : "인증 팝업이 닫힘",
    "Configuration discovery temporarily not available. Please try again later." : "설정 탐색을 현재 이용할 수 없습니다. 나중에 다시 시도하십시오.",
    "There was an error while setting up your account" : "계정을 설정하는 중 오류가 발생했습니다.",
    "Auto" : "자동",
    "Name" : "이름",
    "Mail address" : "메일 주소",
    "Please enter an email of the format name@example.com" : "name@example.com 형식의 이메일을 입력하세요.",
    "Password" : "암호",
    "Manual" : "수동",
    "IMAP Settings" : "IMAP 설정",
    "IMAP Host" : "IMAP 호스트",
    "IMAP Security" : "IMAP 보안",
    "None" : "없음",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 포트",
    "IMAP User" : "IMAP 사용자",
    "IMAP Password" : "IMAP 암호",
    "SMTP Settings" : "SMTP 설정",
    "SMTP Host" : "SMTP 호스트",
    "SMTP Security" : "SMTP 보안",
    "SMTP Port" : "SMTP 포트",
    "SMTP User" : "SMTP 사용자",
    "SMTP Password" : "SMTP 암호",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "이 앱에서 구글 계정을 사용하기 위해서는, 해당 구글 계정에서 2단계 인증을 활성화하고 앱 암호를 생성하십시오",
    "Account settings" : "계정 설정",
    "Aliases" : "별칭",
    "Alias to S/MIME certificate mapping" : "S/MIME 인증 매핑을 위한 별칭",
    "Signature" : "서명",
    "A signature is added to the text of new messages and replies." : "서명이 새로운 메시지 및 전달 메시지의 텍스트에 추가됩니다.",
    "Writing mode" : "쓰기 모드",
    "Preferred writing mode for new messages and replies." : "새 메시지 및 답장을 위한 기본 쓰기 모드입니다.",
    "Default folders" : "기본 폴더",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "임시 보관함, 보낸 편지함, 휴지통, 보관 및 스팸 메일함으로 지정할 폴더입니다.",
    "Automatic trash deletion" : "자동 휴지통 비우기",
    "Days after which messages in Trash will automatically be deleted:" : "다음 일자가 지나면 휴지통의 메시지가 자동으로 삭제됩니다:",
    "Autoresponder" : "자동 응답",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "수신 메시지에 대한 자동 응답입니다. 메시지를 수신한 경우, 이 자동 응답이 최대 4일에 한 번 해당 발신자에게 발송됩니다.",
    "Filters" : "필터",
    "Mail server" : "메일 서버",
    "Update alias" : "별칭 갱신",
    "Rename alias" : "별칭 변경",
    "Show update alias form" : "별칭 양식 갱신 표시",
    "Delete alias" : "별칭 삭제",
    "Go back" : "뒤로 가기",
    "Change name" : "이름 변경",
    "Email address" : "이메일 주소",
    "Add alias" : "별칭 추가",
    "Create alias" : "별칭 만들기",
    "Cancel" : "취소",
    "Search in the body of messages in priority Inbox" : "우선 편지함에서 메시지 본문 검색",
    "Activate" : "활성화",
    "Put my text to the bottom of a reply instead of on top of it." : "내 텍스트를 답장 위가 아니라 답장 맨 아래에 놓기",
    "Could not update preference" : "환경설정을 업데이트할 수 없습니다.",
    "Mail settings" : "메일 설정",
    "Accounts" : "계정",
    "Add mail account" : "메일 계정 추가",
    "General" : "일반",
    "Layout" : "레이아웃",
    "List" : "목록",
    "Vertical split" : "수직 분할",
    "Horizontal split" : "수평 분할",
    "Sorting" : "정렬",
    "Newest" : "최신순",
    "Oldest" : "과거순",
    "Search in body" : "본문 검색",
    "Reply text position" : "답장 문구 위치",
    "Gravatar settings" : "Gravatar 설정",
    "Use Gravatar and favicon avatars" : "Gravatar 및 파비콘 아바타 사용",
    "Register as application for mail links" : "메일 링크를 어플리케이션으로 등록",
    "Register" : "등록",
    "Text blocks" : "텍스트 블록",
    "Create a new text block" : "새로운 텍스트 블록 생성",
    "Privacy and security" : "개인정보 및 보안",
    "Data collection consent" : "데이터 수집 동의",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "앱이 상호 작용에 대한 데이터를 수집하도록 허용합니다. 이 데이터를 기반으로 앱이 사용자의 기본 설정에 맞게 조정됩니다. 데이터는 로컬에만 저장됩니다.",
    "Trusted senders" : "신뢰할 수 있는 발신자",
    "Internal addresses" : "내부 주소",
    "S/MIME" : "S/MIME",
    "Manage S/MIME certificates" : "S/MIME 인증서 관리",
    "Mailvelope" : "Mailvelope",
    "Keyboard shortcuts" : "키보드 단축키",
    "Compose new message" : "새 메시지 작성",
    "Newer message" : "새로운 메시지",
    "Older message" : "오래된 메시지",
    "Toggle star" : "별표 전환",
    "Toggle unread" : "읽음/읽지 않음 전환",
    "Archive" : "보관",
    "Delete" : "삭제",
    "Search" : "검색",
    "Send" : "보내기",
    "Refresh" : "새로 고침",
    "New text block" : "새로운 텍스트 블록",
    "Title of the text block" : "텍스트 블록의 제목",
    "Content of the text block" : "텍스트 블록의 내용",
    "Ok" : "확인",
    "No certificate" : "인증서 없음",
    "Certificate updated" : "인증서 갱신됨",
    "Could not update certificate" : "인증서를 갱신할 수 없음",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - {expiryDate}까지 유효함",
    "Select an alias" : "별칭 선택",
    "Update Certificate" : "인증서 갱신",
    "Encrypt with S/MIME and send later" : "S/MIME로 암호화하고 나중에 보내기",
    "Encrypt with S/MIME and send" : "S/MIME로 암호화하고 보내기",
    "Encrypt with Mailvelope and send later" : "Mailvelope로 암호화하고 나중에 보내기",
    "Encrypt with Mailvelope and send" : "Mailvelope로 암호화하고 보내기",
    "Send later" : "나중에 보내기",
    "Message {id} could not be found" : "메시지 {id}을(를) 찾을 수 없습니다",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "S/MIME으로 암호화하기 또는 서명하기가 선택되었지만 선택된 별칭에 대한 인증서가 없습니다. 메시지는 서명 또는 인증되지 않을 것입니다.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "모든 서식(굵은 글꼴, 기울임꼴, 밑줄, 인라인 이미지 등)이 삭제됩니다.",
    "Turn off formatting" : "서식 끄기",
    "Turn off and remove formatting" : "서식을 끄고 삭제하기",
    "Keep formatting" : "서식 유지하기",
    "From" : "보낸사람",
    "Select account" : "계정 선택",
    "To" : "받는사람",
    "Select recipient" : "수신자 지정",
    "Contact or email address …" : "연락처 또는 이메일 주소 ...",
    "Cc" : "참조",
    "Bcc" : "숨은참조",
    "Subject" : "제목",
    "Subject …" : "제목...",
    "This message came from a noreply address so your reply will probably not be read." : "발신 전용 주소에서 보낸 메시지이므로 답장이 전달되지 않을 수 있습니다.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "다음 받는이가 S/MIME 인증서를 가지고 있지 않습니다: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "다음의 받는이는 PGP key가 없습니다:{recipients}.",
    "Write message …" : "메시지 작성중...",
    "Saving draft …" : "초안 저장 중...",
    "Error saving draft" : "초안을 저장하는 중에 오류가 발생했습니다.",
    "Draft saved" : "초안 저장됨",
    "Save draft" : "초안 저장",
    "Discard & close draft" : "초안을 버리고 닫기",
    "Enable formatting" : "서식 활성화",
    "Disable formatting" : "서식 비활성화",
    "Upload attachment" : "첨부 파일 업로드",
    "Add attachment from Files" : "파일 앱에서 첨부 파일 추가",
    "Smart picker" : "스마트 피커",
    "Request a read receipt" : "수신 확인 요청",
    "Sign message with S/MIME" : "메시지를 S/MIME로 서명하기",
    "Encrypt message with S/MIME" : "메시지를 S/MIME로 암호화하기",
    "Encrypt message with Mailvelope" : "Mailvelope로 메시지 암호화",
    "Send now" : "지금 보내기",
    "Tomorrow morning" : "내일 아침",
    "Tomorrow afternoon" : "내일 오후",
    "Monday morning" : "월요일 아침",
    "Custom date and time" : "사용자 지정 날짜 및 시간",
    "Enter a date" : "날짜 입력",
    "Choose" : "선택",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["첨부파일이 허용 용량 {size}를 초과했습니다. 해당 파일을 첨부 대신 링크공유하십시오."],
    "Choose a file to add as attachment" : "첨부할 파일을 선택하십시오",
    "Choose a file to share as a link" : "공유할 링크 파일을 선택하세요.",
    "_{count} attachment_::_{count} attachments_" : ["{count}개의 첨부파일"],
    "Untitled message" : "제목 없는 메시지",
    "Confirm" : "확인",
    "Tag: {name} deleted" : "태그: {name}이(가) 삭제됨",
    "An error occurred, unable to delete the tag." : "오류가 발생하여 태그를 삭제할 수 없습니다",
    "The tag will be deleted from all messages." : "태그가 모든 메시지로부터 삭제됩니다.",
    "Plain text" : "평문",
    "Rich text" : "서식 있는 텍스트",
    "No messages in this folder" : "이 폴더에 메시지가 없음",
    "No messages" : "메시지가 없음",
    "No subject" : "제목 없음",
    "Later today – {timeLocale}" : "오늘 나중 – {timeLocale}",
    "Set reminder for later today" : "알림을 오늘 나중에 설정",
    "Tomorrow – {timeLocale}" : "내일 – {timeLocale}",
    "Set reminder for tomorrow" : "알림을 내일로 설정",
    "This weekend – {timeLocale}" : "이번 주말 – {timeLocale}",
    "Set reminder for this weekend" : "알림을 주말로 설정",
    "Next week – {timeLocale}" : "다음주 – {timeLocale}",
    "Set reminder for next week" : "알림을 다음주로 설정",
    "Could not delete message" : "메시지를 삭제할 수 없음",
    "Could not archive message" : "메시지를 보관할 수 없음",
    "Thread was snoozed" : "쓰레드가 다시 알림 설정됨",
    "Could not snooze thread" : "쓰레드를 다시 알림 설정할 수 없음",
    "Thread was unsnoozed" : "쓰레드의 다시 알림 설정을 해제함",
    "Could not unsnooze thread" : "쓰레드의 다시 알림 설정을 해제할 수 없음",
    "Encrypted message" : "암호화된 메시지",
    "This message is unread" : "읽지 않은 메시지입니다",
    "Unfavorite" : "즐겨찾기에서 삭제",
    "Favorite" : "즐겨찾기",
    "Unread" : "읽지 않음",
    "Read" : "읽기",
    "Unimportant" : "중요하지 않음",
    "Mark not spam" : "스팸 해제",
    "Mark as spam" : "스팸 신고",
    "Edit tags" : "태그 편집",
    "Snooze" : "다시 알림",
    "Unsnooze" : "다시 알림 해제",
    "Move thread" : "쓰레드 이동",
    "Archive thread" : "쓰레드 보관",
    "Archive message" : "메시지 보관",
    "Delete thread" : "쓰레드 삭제",
    "Delete message" : "메시지 삭제",
    "More actions" : "더 많은 동작",
    "Back" : "뒤로",
    "Set custom snooze" : "사용자 지정 다시 알림 사용",
    "Edit as new message" : "새 메시지로 편집",
    "Create task" : "작업 만들기",
    "Download message" : "메시지 다운로드",
    "Load more" : "더 불러오기",
    "_Mark {number} read_::_Mark {number} read_" : ["{number}을(를) 읽음으로 표시"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["{number}을(를) 읽지 않음으로 표시"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["{number}을(를) 중요로 표시"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["{number}을(를) 중요하지 않음으로 표시"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["{number}을(를) 즐겨찾기에서 해제"],
    "_Favorite {number}_::_Favorite {number}_" : ["{number}을(를) 즐겨찾기로 지정"],
    "_Unselect {number}_::_Unselect {number}_" : ["{number} 선택 해제"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["{number}을(를) 스팸으로 표시"],
    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["{number}의 스팸 표시를 해제"],
    "_Edit tags for {number}_::_Edit tags for {number}_" : ["{number}의 태그 편집"],
    "_Move {number} thread_::_Move {number} threads_" : ["쓰레드 {number} 이동"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["{number}을(를) 첨부파일로 전달"],
    "Mark as unread" : "읽지 않은 것으로 표시",
    "Mark as read" : "읽은 것으로 표시",
    "Report this bug" : "이 오류 보고",
    "Event created" : "일정 생성됨",
    "Could not create event" : "일정을 생성할 수 없음",
    "Create event" : "일정 만들기",
    "All day" : "하루 종일",
    "Attendees" : "참석자",
    "Select calendar" : "달력 선택",
    "Description" : "설명",
    "Create" : "생성",
    "This event was updated" : "이 일정이 갱신되었습니다",
    "{attendeeName} accepted your invitation" : "{attendeeName}이(가) 초대를 수락했습니다",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName}이(가) 초대를 잠정 수락했습니다",
    "{attendeeName} declined your invitation" : "{attendeeName}이(가) 초대를 거절했습니다",
    "{attendeeName} reacted to your invitation" : "{attendeeName}이(가) 초대에 반응했습니다",
    "Failed to save your participation status" : "참가 여부를 저장하지 못했습니다",
    "You accepted this invitation" : "초대를 수락했습니다",
    "You tentatively accepted this invitation" : "초대를 잠정 수락했습니다",
    "You declined this invitation" : "초대를 거절했습니다",
    "You already reacted to this invitation" : "이 초대에 이미 반응했습니다",
    "You have been invited to an event" : "일정에 초대됨",
    "This event was cancelled" : "이 일정은 취소되었습니다",
    "Save to" : "다음에 저장",
    "Select" : "선택",
    "Comment" : "설명",
    "Accept" : "수락",
    "Decline" : "거절",
    "Tentatively accept" : "잠정 수락",
    "More options" : "더 많은 옵션",
    "individual" : "개별",
    "domain" : "도메인",
    "Remove" : "삭제",
    "email" : "이메일",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "이 메시지를 보관 폴더로 옮기거나 현재 폴더에서 삭제할 수 없습니다",
    "Today" : "오늘",
    "Yesterday" : "어제",
    "Last week" : "지난 주",
    "Loading messages …" : "메시지를 불러오는 중 ...",
    "Choose target folder" : "폴더 선택",
    "No more submailboxes in here" : "더 이상의 하위 편지함 없음",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "사용자의 메시지 상호작용, 중요 표시 정보 등을 바탕으로 특정 메시지가 자동으로 중요 표시됩니다. 초기 단계에서는 시스템의 학습을 위해 사용자가 중요 여부를 수동으로 변경하게 될 수 있으나, 이는 점차 개선될 것입니다.",
    "Important info" : "중요 정보",
    "Other" : "기타",
    "Could not send mdn" : "mdn을 보낼 수 없음",
    "The sender of this message has asked to be notified when you read this message." : "이 메시지의 발신자는 당신의 메시지 열람 여부에 대한 알림을 요청했습니다.",
    "Notify the sender" : "발신자에게 알림",
    "You sent a read confirmation to the sender of this message." : "이 메시지의 발신자에게 열람 확인을 전송했습니다.",
    "Message was snoozed" : "메시지가 다시 알림 설정됨",
    "Could not snooze message" : "메시지를 다시 알림 설정할 수 없음",
    "Message was unsnoozed" : "메시지의 다시 알림 설정을 해제함",
    "Could not unsnooze message" : "메시지의 다시 알림 설정을 해제할 수 없음",
    "Forward" : "전달",
    "Move message" : "메시지 이동",
    "Translate" : "번역:",
    "Forward message as attachment" : "메시지를 첨부파일로 전달",
    "View source" : "원본 보기",
    "Download thread data for debugging" : "디버깅을 위한 쓰레드 데이터 다운로드",
    "Message body" : "메시지 본문",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "주의: 이 메시지의 S/MIME 서명을 확인할 수 없습니다. 사칭된 발신자일 수 있습니다.",
    "Unnamed" : "이름 없음",
    "Embedded message" : "포함된 메시지",
    "calendar imported" : "달력 가져옴",
    "Choose a folder to store the attachment in" : "첨부 항목을 저장할 폴더 선택",
    "Import into calendar" : "달력으로 가져오기",
    "Download attachment" : "첨부 파일 다운로드",
    "Save to Files" : "파일에 저장",
    "Choose a folder to store the attachments in" : "첨부 파일을 저장할 폴더 선택",
    "Save all to Files" : "모두 저장",
    "Download Zip" : "Zip 파일 다운로드",
    "_View {count} more attachment_::_View {count} more attachments_" : ["{count}개의 첨부파일 더 보기"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "이 메시지는 PGP로 암호화되었습니다. Mailvelope를 설치하여 해제하십시오",
    "The images have been blocked to protect your privacy." : "개인 정보를 보호하기 위해 사진을 차단했습니다.",
    "Show images" : "이미지 보기",
    "Show images temporarily" : "임시로 이미지 보기",
    "Always show images from {sender}" : "{sender}이(가) 보낸 이미지를 항상 보기",
    "Always show images from {domain}" : "{domain}(으)로부터 발신된 이미지를 항상 보기",
    "Quoted text" : "인용된 문구",
    "Move" : "이동",
    "Moving" : "이동 중",
    "Moving thread" : "쓰레드 이동 중",
    "Moving message" : "메시지 이동 중",
    "Remove account" : "계정 삭제",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email} 계정 및 캐시된 이메일 데이터가 Nextcloud에서 삭제되지만, 이메일 서비스 제공자에서 삭제되지는 않습니다.",
    "Remove {email}" : "{email} 제거",
    "Provisioned account is disabled" : "프로비전된 계정을 비활성화 했습니다",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "이 계정을 활성화 하기 위해 암호를 사용하여 로그인 하십시오. 현재 세션은 무암호 인증을 사용하고 있습니다. 예) SSO, WebAuthn",
    "Add folder" : "폴더 추가",
    "Folder name" : "폴더 이름",
    "Saving" : "저장 중",
    "Move up" : "위로 이동",
    "Move down" : "아래로 이동",
    "Show all subscribed folders" : "구독 폴더 모두 표시",
    "Show all folders" : "모든 폴더 보기",
    "Collapse folders" : "폴더 접기",
    "_{total} message_::_{total} messages_" : ["{total} 개의 메시지"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} 개 중 {unread} 개 읽지 않음"],
    "Loading …" : "불러오는 중 …",
    "All messages in mailbox will be deleted." : "편지함에 있는 모든 메시지가 삭제됩니다",
    "Clear mailbox {name}" : "편지함 {name} 비우기",
    "Delete folder" : "폴더 삭제",
    "Delete folder {name}" : "{name} 폴더 삭제",
    "An error occurred, unable to rename the mailbox." : "오류가 발생하여 편지함의 이름을 변경할 수 없습니다.",
    "Mark all as read" : "모두 읽은 것으로 표시",
    "Add subfolder" : "하위 폴더 추가",
    "Rename" : "이름 바꾸기",
    "Move folder" : "폴더 이동",
    "Clear cache" : "Clear cache",
    "Clear locally cached data, in case there are issues with synchronization." : "동기화 관련 문제가 발생했을 경우 로컬에서 캐시된 데이터를 비우십시오.",
    "Subscribed" : "구독함",
    "Sync in background" : "백그라운드에서 동기화",
    "Outbox" : "보낸 편지함",
    "New message" : "새로운 메시지",
    "Edit message" : "메시지 편집",
    "Draft" : "초안",
    "Reply" : "답장",
    "Message saved" : "메시지 저장됨",
    "Failed to save message" : "메시지를 저장할 수 없음",
    "Failed to save draft" : "초안을 저장할 수 없음",
    "attachment" : "첨부파일",
    "attached" : "첨부됨",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "다수의 수신자와 참조에게 메시지를 발신하려고 합니다. 수신자 주소를 숨기기 위해 Bcc 사용을 고려하십시오.",
    "You mentioned an attachment. Did you forget to add it?" : "메시지에서 첨부파일을 언급했습니다. 첨부 여부를 확인하셨습니까?",
    "Message discarded" : "메시지 폐기됨",
    "Could not discard message" : "메시지를 폐기할 수 없음",
    "Error sending your message" : "당신의 메시지 보내기 오류",
    "Retry" : "다시 시도",
    "Warning sending your message" : "메시지 전송 경고",
    "Send anyway" : "무시하고 보내기",
    "Start writing a message by clicking below or select an existing message to display its contents" : "아래 버튼을 눌러 새로운 메시지를 작성하거나 기존 메시지를 선택하여 내용을 확인하세요",
    "Autoresponder off" : "자동 응답 끄기",
    "Autoresponder on" : "자동 응답 켜기",
    "Autoresponder follows system settings" : "자동 응답은 시스템 설정을 따릅니다",
    "The autoresponder follows your personal absence period settings." : "자동 응답은 개인 부재 설정을 따릅니다.",
    "Edit absence settings" : "부재 설정 편집",
    "First day" : "첫 날",
    "Last day (optional)" : "마지막 날 (선택사항)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject}이(가) 다음에 답장하고자 하는 메시지의 제목으로 대체될 것입니다",
    "Message" : "메시지",
    "Save autoresponder" : "자동 응답 저장",
    "Could not open outbox" : "보낸 편지함을 열 수 없음",
    "Pending or not sent messages will show up here" : "진행 중이거나 전송되지 않은 메시지가 여기에 표시됩니다",
    "Message could not be sent" : "메시지를 보낼 수 없습니다",
    "Message deleted" : "메시지 삭제됨",
    "Copied email address to clipboard" : "이메일 주소를 클립보드에 복사함",
    "Could not copy email address to clipboard" : "이메일 주소를 클립보드에 복사할 수 없음",
    "Contacts with this address" : "이 주소를 가진 연락처",
    "Add to Contact" : "연락처 추가",
    "New Contact" : "새 연락처",
    "Copy to clipboard" : "클립보드로 복사",
    "Contact name …" : "연락처 이름 ...",
    "Add" : "추가",
    "Show less" : "적게 보기",
    "Show more" : "더 보기",
    "Clear" : "비우기",
    "Search in folder" : "폴더에서 검색",
    "Close" : "닫기",
    "Search parameters" : "검색 인자",
    "Search subject" : "제목 검색",
    "Body" : "몸통",
    "Search body" : "본문 검색",
    "Date" : "날짜",
    "Pick a start date" : "시작일 선택",
    "Pick an end date" : "종료일 선택",
    "Select senders" : "발신자 지정",
    "Select recipients" : "받는이 선택",
    "Select CC recipients" : "CC 받는이 선택",
    "Select BCC recipients" : "BCC 받는이 선택",
    "Tags" : "태그",
    "Select tags" : "태그 선택",
    "Marked as" : "다음으로 표시됨",
    "Has attachments" : "첨부파일 있음",
    "Last 7 days" : "지난 7일",
    "Enable mail body search" : "메일 본문 검색 활성화",
    "Sieve Port" : "Sieve 포트",
    "Custom" : "사용자 정의",
    "Sieve User" : "Sieve 사용자",
    "Sieve Password" : "Sieve 암호",
    "Save sieve settings" : "Sieve 설정 저장",
    "The syntax seems to be incorrect:" : "문법이 잘못된 것 같습니다:",
    "Save sieve script" : "Sieve 스크립트 저장",
    "Signature …" : "서명 …",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "서명이 2 MB를 초과합니다. 편집기의 성능에 영향을 미칠 수 있습니다.",
    "Save signature" : "서명 저장",
    "Place signature above quoted text" : "인용 문구 상단에 서명 삽입",
    "Message source" : "메시지 원본",
    "An error occurred, unable to rename the tag." : "오류가 발생하여 태그 이름을 변경할 수 없습니다",
    "Edit name or color" : "이름 또는 색깔 편집",
    "Saving new tag name …" : "새 태그명 저장 ...",
    "Delete tag" : "태그 삭제",
    "Set tag" : "태그 설정",
    "Unset tag" : "태그 설정 해제",
    "Tag name is a hidden system tag" : "태그 이름이 숨겨진 시스템 태그입니다",
    "Tag already exists" : "태그가 이미 존재합니다.",
    "Tag name cannot be empty" : "태그 이름을 비울 수 없음",
    "An error occurred, unable to create the tag." : "오류가 발생하여 태그 이름을 생성할 수 없습니다",
    "Add default tags" : "기본 태그 추가",
    "Add tag" : "태그 추가",
    "Saving tag …" : "태그 저장하는 중 ...",
    "Task created" : "작업이 생성됨",
    "Could not create task" : "작업을 만들 수 없음",
    "No calendars with task list support" : "작업 목록을 지원하는 달력 없음",
    "Summarizing thread failed." : "쓰레드 요약 실패",
    "Could not load your message thread" : "메시지 쓰레드를 불러올 수 없음",
    "The thread doesn't exist or has been deleted" : "쓰레드가 존재하지 않거나 삭제되었습니다",
    "Loading thread" : "쓰레드 불러오는 중",
    "Not found" : "찾을 수 없음",
    "Encrypted & verified " : "암호화 및 확인됨",
    "Signature verified" : "서명 확인됨",
    "Signature unverified " : "서명이 확인되지 않음",
    "This message was encrypted by the sender before it was sent." : "발신자가 발신 전 이 메시지를 암호화했습니다",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "이 메시지는 확인된 디지털 S/MIME 서명을 포함하고 있습니다. 발신된 시점으로부터 변경된 내용이 없습니다.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "이 메시지는 확인되지 않은 디지털 S/MIME 서명을 포함하고 있습니다. 발신된 시점 이후 변경된 내용이 존재하거나 해당 서명자의 인증서가 신뢰할 수 없는 상태입니다.",
    "Reply all" : "모두에게 답장",
    "Unsubscribe request sent" : "구독 해지 요청을 보냄",
    "Could not unsubscribe from mailing list" : "메일링 리스트의 구독을 해지할 수 없음",
    "Unsubscribe" : "구독 취소",
    "Reply to sender only" : "발신자에게만 답장",
    "Mark as unfavorite" : "즐겨찾기에서 해제",
    "Mark as favorite" : "즐겨찾기로 표시",
    "Unsubscribe via link" : "링크로 구독 해지",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "구독 해지는 메일링 리스트 {sender}이(가) 보내는 모든 메시지의 발신을 정지합니다",
    "Send unsubscribe email" : "구독 해지 이메일 보내기",
    "Unsubscribe via email" : "이메일로 구독 해지",
    "Go to latest message" : "최근 메시지로 가기",
    "The message could not be translated" : "메시지를 번역할 수 없습니다.",
    "Translation copied to clipboard" : "번역을 클립보드로 복사함",
    "Translation could not be copied" : "번역을 복사할 수 없습니다.",
    "Translate message" : "메시지 번역",
    "Source language to translate from" : "번역될 원본의 언어",
    "Translate from" : "다음을 번역",
    "Target language to translate into" : "번역할 목표 언어",
    "Translate to" : "다음으로 번역",
    "Translating" : "번역 중",
    "Copy translated text" : "번역한 텍스트 복사",
    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "입력 필드를 비우거나 0으로 지정하여 휴지통 보관을 비활성화하십시오. 휴지통 보관 활성화 이후 삭제된 메일만 휴지통에서 처리됩니다.",
    "Could not remove trusted sender {sender}" : "신뢰하는 발신자 {sender}을(를) 삭제할 수 없음",
    "No senders are trusted at the moment." : "현재 신뢰하는 발신자가 없습니다.",
    "Untitled event" : "제목 없는 일정",
    "(organizer)" : "(주최자)",
    "Import into {calendar}" : "{calendar}(으)로 가져오기",
    "Event imported into {calendar}" : "일정을 {calendar}에 불러옴",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{depAirport}에서 {arrAirport}(으)로 향하는 {flightNr}번 항공편",
    "Airplane" : "여객기",
    "Reservation {id}" : "예약 {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{depStation}에서 {arrStation}(으)로 향하는 {trainNr}번 열차",
    "Train from {depStation} to {arrStation}" : "{depStation}에서 {arrStation}(으)로 향하는 열차",
    "Train" : "기차",
    "Recipient" : "받는 사람",
    "Delete filter" : "필터 삭제",
    "contains" : "다음을 포함함",
    "matches" : "일치함",
    "Priority" : "우선 순위",
    "delete" : "삭제",
    "Edit" : "편집",
    "Successfully updated config for \"{domain}\"" : "\"{domail}\"에 대한 설정을 성공적으로 갱신함",
    "Error saving config" : "설정을 저장하는 중 오류 발생",
    "Saved config for \"{domain}\"" : "\"{domail}\"에 대한 설정을 저장함",
    "Could not save provisioning setting" : "프로비전 설정을 저장할 수 없음",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["{count}개의 계정을 성공적으로 프로비전 함"],
    "There was an error when provisioning accounts." : "계정 프로비전 중 오류 발생",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "\"{domain}\"에 해당하는 계정을 성공적으로 삭제, 프로비전 해제함",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "\"{domain}\"에 해당하는 계정을 삭제, 프로비전 해제하는 중 오류 발생",
    "Mail app" : "Mail 앱",
    "The mail app allows users to read mails on their IMAP accounts." : "Mail 앱은 사용자가 자신의 IMAP 계정에서 이메일을 읽을 수 있도록 합니다.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "이곳에서 인스턴스 전체에 적용되는 설정을 확인할 수 있습니다. 특정 사용자를 대상으로 하는 설정은 앱 자체에서 확인할 수 있습니다. (좌하단 구석)",
    "Account provisioning" : "계정 프로비전",
    "A provisioning configuration will provision all accounts with a matching email address." : "프로비전 설정은 일치하는 이메일 주소로 모든 계정을 프로비전할 것입니다.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "프로비전 도메인 필드에 와일드카드(*)를 입력할 경우 별도의 설정이 지정되지 않은 모든 사용자에게 새로운 설정을 생성하여 적용합니다.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "프로비전은 지정된 도메인 설정을 우선 처리하고 와일드카드 도메인 설정을 그 다음에 처리합니다.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "새로운 설정이 이미 다른 설정으로 프로비전된 사용자에게서 발견될 경우, 새로운 설정이 우선 적용됩니다.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "한 도메인에 대해 하나의 와일드 카드 설정만 존재할 수 있습니다.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "모든 사용자에 대해 프로비전을 하고자 할 경우, 와일드카드(*)를 사용하십시오.",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "이 설정은 조직의 Nextcloud와 메일 서버가 같은 사용자 백엔드를 사용할 경우에만 효력이 있습니다.",
    "Provisioning Configurations" : "프로비전 설정",
    "Add new config" : "새 설정 추가",
    "Provision all accounts" : "모든 계정 프로비전",
    "Allow additional mail accounts" : "추가 이메일 계정 허용",
    "Allow additional Mail accounts from User Settings" : "사용자 설정에서 추가 이메일 계정 설정을 허용",
    "Anti Spam Service" : "스팸 차단 서비스",
    "You can set up an anti spam service email address here." : "이곳에서 스팸 차단 서비스 이메일 주소를 설정할 수 있습니다.",
    "Any email that is marked as spam will be sent to the anti spam service." : "스팸으로 표시된 모든 이메일은 스팸 차단 서비스로 전송됩니다.",
    "Gmail integration" : "Gmail 통합",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "사용자는 IMAP을 통해 Gmail에 접근할 수 있습니다. 단, 보안을 위해 OAuth 2.0 연결 또는 2단계 인증과 앱 압호를 사용하는 Google 계정만 허용합니다.",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Google Cloud 콘솔의 \"웹 애플리케이션\"에서 새 클라이언트 ID를 등록할 수 있습니다. URL {url}을(를) 인증된 리다이렉트 URI로 추가하십시오",
    "Microsoft integration" : "Microsoft 통합",
    "Successfully set up anti spam email addresses" : "스팸 차단 이메일 주소를 성공적으로 설정함",
    "Error saving anti spam email addresses" : "스팸 차단 이메일 주소를 저장하는 중 오류 발생",
    "Successfully deleted anti spam reporting email" : "스팸 차단 보고 이메일을 성공적으로 삭제함",
    "Error deleting anti spam reporting email" : "스팸 차단 보고 이메일을 삭제하는 중 오류 발생",
    "Anti Spam" : "스팸 차단",
    "Add the email address of your anti spam report service here." : "사용할 스팸 차단 서비스의 이메일 주소를 이곳에서 추가하십시오.",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "이 설정을 사용하면, 사용자가 \"스팸으로 표시\"를 클릭할 때 신고 이메일이 SPAM 보고 서버로 전송됩니다.",
    "The original message will be attached as a \"message/rfc822\" attachment." : "원본 메시지는 \"message/rfc822\"로 첨부됩니다.",
    "\"Mark as Spam\" Email Address" : "\"스팸으로 표시\" 이메일 주소",
    "\"Mark Not Junk\" Email Address" : "\"스팸 메일 아님\" 이메일 주소",
    "Reset" : "초기화",
    "Google integration configured" : "Google 통합이 설정됨",
    "Could not configure Google integration" : "Google 통합을 설정할 수 없음",
    "Google integration unlinked" : "Google 통합이 해제됨",
    "Could not unlink Google integration" : "Google 통합을 해제할 수 없음",
    "Client ID" : "클라이언트 ID",
    "Client secret" : "클라이언트 비밀 값",
    "Unlink" : "해제",
    "Microsoft integration configured" : "Microsoft 통합이 설정됨",
    "Could not configure Microsoft integration" : "Microsoft 통합을 설정할 수 없음",
    "Microsoft integration unlinked" : "Microsoft 통합이 해제됨",
    "Could not unlink Microsoft integration" : "Microsoft 통합을 해제할 수 없음",
    "Domain Match: {provisioningDomain}" : "도메인 일치: {provisioningDomail}",
    "Email: {email}" : "이메일: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {host}:{port} ({ssl} 암호화)의 사용자 {user}",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {host}:{port} ({ssl} 암호화)의 사용자 {user}",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {host}:{port} ({ssl} 암호화)의 사용자 {user}",
    "Configuration for \"{provisioningDomain}\"" : "\"{provisioningDomain}\" 설정",
    "Provisioning domain" : "도메인 프로비전",
    "Email address template" : "이메일 주소 형식",
    "IMAP" : "IMAP",
    "User" : "사용자",
    "Host" : "호스트",
    "Port" : "포트",
    "SMTP" : "SMTP",
    "Master password" : "마스터 암호",
    "Use master password" : "마스터 암호 사용",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "Sieve 통합 활성화",
    "LDAP aliases integration" : "LDAP 별칭 통합",
    "Enable LDAP aliases integration" : "LDAP 별칭 통합 활성화",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP 별칭에 대한 통합 체계가 이메일 별칭 프로비전을 위해 설정된 LDAP 디렉토리로부터 속성값을 읽습니다.",
    "LDAP attribute for aliases" : "별칭에 대한 LDAP 속성",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "이메일 별칭 프로비전을 위한 복수의 속성값. 각 값에 대해 별칭이 생성됩니다. Nextcloud에 존재하는 별칭 중 LDAP 디렉토리에 없는 것은 삭제됩니다.",
    "Save Config" : "설정 저장",
    "Unprovision & Delete Config" : "프로비전 해제 및 삭제 설정",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID%와(과) %EMAIL%이(가) 사용자의 UID와 이메일로 대체됩니다",
    "With the settings above, the app will create account settings in the following way:" : "상단의 설정을 통해, 앱은 다음의 방법으로 계정 설정을 생성합니다: ",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "제공된 PKCS #12 인증서는 최소 하나의 인증서와 정확히 하나의 개인 키를 포함하여야 합니다.",
    "Failed to import the certificate. Please check the password." : "인증서를 불러올 수 없음. 암호를 확인하십시오.",
    "Certificate imported successfully" : "인증서를 성공적으로 불러옴",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "인증서를 불러올 수 없음. 개인 키와 인증서의 연동 및 개인 키의 암구호 미사용 여부를 확인하십시오.",
    "Failed to import the certificate" : "인증서를 가져올 수 없음",
    "S/MIME certificates" : "S/MIME 인증서",
    "Certificate name" : "인증서 이름",
    "E-mail address" : "이메일 주소",
    "Valid until" : "만료 기간:",
    "Delete certificate" : "인증서 삭제",
    "No certificate imported yet" : "가져온 인증서 없음",
    "Import certificate" : "인증서 가져오기",
    "Import S/MIME certificate" : "S/MIME 인증서 가져오기",
    "PKCS #12 Certificate" : "PKCS #12 인증서",
    "PEM Certificate" : "PEM 인증서",
    "Certificate" : "인증서",
    "Private key (optional)" : "개인 키 (선택사항)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "개인 키는 이 인증서를 사용하여 서명하거나 암호화한 이메일을 보낼 때만 사용됩니다",
    "Submit" : "제출",
    "No text blocks available" : "텍스트 블록이 없습니다",
    "Text block deleted" : "텍스트 블록 삭제됨",
    "Failed to delete text block" : "텍스트 블록을 삭제하지 못했습니다",
    "Text block shared with {sharee}" : "{sharee}와(과) 텍스트 블록 공유함",
    "Failed to share text block with {sharee}" : "텍스트 블록을 {sharee}와(과) 공유하지 못했습니다",
    "Failed to save text block" : "텍스트 블록을 저장하지 못했습니다",
    "Shared" : "공유됨",
    "Edit text block" : "텍스트 블록 수정",
    "Shares" : "공유",
    "Choose a text block to insert at the cursor" : "커서에 삽입할 텍스트 블록을 선택하세요",
    "Insert" : "삽입",
    "Insert text block" : "텍스트 블록 삽입",
    "Account connected" : "계정 연결됨",
    "You can close this window" : "윈도우를 닫으셔도 됩니다",
    "Connect your mail account" : "메일 계정에 연결",
    "To add a mail account, please contact your administrator." : "이메일 계정 추가는 관리자에게 문의하십시오.",
    "All" : "모두",
    "Drafts" : "임시 보관함",
    "Favorites" : "즐겨찾기",
    "Priority inbox" : "우선 편지함",
    "All inboxes" : "모든 받은 편지함",
    "Inbox" : "받은 편지함",
    "Junk" : "스팸 메일함",
    "Sent" : "보낸 편지함",
    "Trash" : "휴지통",
    "Connect OAUTH2 account" : "OAUTH2 계정 연결",
    "Error while sharing file" : "파일 공유하는 도중 오류 발생",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["새 메일 %n개\n보낸 사람: {from}"],
    "Nextcloud Mail" : "Nextcloud 메일",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "작업 중인 메시지가 있습니다. 계속 진행할 경우 저장되지 않은 변경 사항이 모두 사라집니다!",
    "Discard changes" : "변경 사항 버리기",
    "Discard unsaved changes" : "저장되지 않은 변경 사항 버리기",
    "Keep editing message" : "계속 메시지 편집하기",
    "Attachments were not copied. Please add them manually." : "첨부파일이 복제되지 않았습니다. 수동으로 추가하십시오.",
    "Could not create snooze mailbox" : "다시 알림 편지함을 생성할 수 없음",
    "Message sent" : "보낸 메시지",
    "Could not send message" : "메시지를 보낼 수 없음",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러올 수 없음",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러오는 중 문제 발생",
    "Could not load your message" : "메시지를 불러올 수 없음",
    "Could not load the desired message" : "원하는 메시지를 불러올 수 없음",
    "Could not load the message" : "메시지를 불러올 수 없음",
    "Error loading message" : "메시지 불러오기 오류",
    "Forwarding to %s" : "%s 전달",
    "Click here if you are not automatically redirected within the next few seconds." : "자동으로 이동하지 않는 경우 여기를 클릭하십시오.",
    "Redirect" : "넘겨주기",
    "The link leads to %s" : "이 링크가 %s을(를) 향함",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "해당 페이지를 방문하지 않으려면 <a href=\"%s\">메일</a>로 돌아갈 수 있습니다.",
    "Continue to %s" : "%s(으)로 이동",
    "Mailvelope is enabled for the current domain!" : "Mailvelope이 현재 도메인에 대해 활성화되어 있습니다!",
    "Looking for a way to encrypt your emails?" : "이메일을 암호화하는 방법을 찾고 계십니까?",
    "Install Mailvelope browser extension" : "Mailvelope 브라우저 확장 설치",
    "Enable Mailvelope for the current domain" : "현재 도메인에 Mailvelope 활성화하기",
    "Flag" : "깃발",
    "Operator" : "운영자",
    "Filter name" : "필터 이름"
},
"nplurals=1; plural=0;");
